@@ -17,8 +17,10 @@ import io
 import os
 import os.path as osp
 import pdb
+import re
 import shlex
 import sys
+import sysconfig
 import time
 import warnings
 
@@ -539,7 +541,8 @@ class UserModuleReloader(object):
         # pytorch: see issue 7041
         # fastmat: see issue 7190
         # pythoncom: see issue 7190
-        other_modules = ['pytorch', 'pythoncom']
+        # tensorflow: see issue 8697
+        other_modules = ['pytorch', 'pythoncom', 'tensorflow']
         if PY2:
             py2_modules = ['astropy', 'fastmat']
             other_modules = other_modules + py2_modules
@@ -550,6 +553,20 @@ class UserModuleReloader(object):
         self.pathlist = pathlist
         self.previous_modules = list(sys.modules.keys())
 
+    @property
+    def skip_paths(self):
+        """Python library paths to be skipped from module reloading."""
+        try:
+            paths = sysconfig.get_paths()
+            lib_paths = [paths['stdlib'],
+                         paths['purelib'],
+                         paths['scripts'],
+                         paths['data']]
+
+            return lib_paths
+        except Exception:
+            return []
+
     def is_module_blacklisted(self, modname, modpath):
         if HAS_CYTHON:
             # Don't return cached inline compiled .PYX files
@@ -560,6 +577,37 @@ class UserModuleReloader(object):
         else:
             return set(modname.split('.')) & set(self.namelist)
 
+    def is_module_reloadable(self, module):
+        """Decide if a module can be reloaded or not."""
+        modpath = getattr(module, '__file__', None)
+
+        # Skip module according to different criteria
+        if modpath is None:
+            # *module* is a C module that is statically linked into the
+            # interpreter. There is no way to know its path, so we
+            # choose to ignore it.
+            return False
+        elif any([p in modpath for p in self.skip_paths]):
+            # We don't want to reload modules that belong to the
+            # standard library or installed to site-packages,
+            # just modules created by the user.
+            return False
+        elif not os.name == 'nt':
+            # Module paths containing the strings below can be ihherited
+            # from the default Linux installation or Homebrew in a
+            # virtualenv.
+            patterns = [r'^/usr/lib.*',
+                        r'^/usr/local/lib.*',
+                        r'^/usr/.*/dist-packages/.*',
+                        r'^/Library/.*'
+            ]
+            if [p for p in patterns if re.search(p, modpath)]:
+                return False
+            else:
+                return True
+        else:
+            return True
+
     def run(self, verbose=False):
         """
         Del user modules to force Python to deeply reload them
@@ -571,15 +619,16 @@ class UserModuleReloader(object):
         log = []
         for modname, module in list(sys.modules.items()):
             if modname not in self.previous_modules:
-                modpath = getattr(module, '__file__', None)
-                if modpath is None:
-                    # *module* is a C module that is statically linked into the
-                    # interpreter. There is no way to know its path, so we
-                    # choose to ignore it.
+                # Decide if a module can be reloaded or not
+                if not self.is_module_reloadable(module):
                     continue
+
+                # Reload module
                 if not self.is_module_blacklisted(modname, modpath):
                     log.append(modname)
                     del sys.modules[modname]
+
+        # Report reloaded modules
         if verbose and log:
             _print("\x1b[4;33m%s\x1b[24m%s\x1b[0m"\
                    % ("Reloaded modules", ": "+", ".join(log)))
